@@ -8,37 +8,36 @@
 #' @param X A matrix or data frame where each row is a time series, or a list where each element is
 #'   a time series. Multivariate series should be provided as a list of matrices where time spans
 #'   the rows and the variables span the columns.
-#' @param centroid Optionally, a time series to use as reference. Defaults to a random series of
-#'   \code{X} if \code{NULL}. For multivariate series, this should be a matrix with the same
-#'   characteristics as the matrices in \code{X}. \emph{It will be z-normalized}.
-#' @param znorm Logical flag. Should z-scores be calculated for \code{X} before processing?
+#' @param centroid Optionally, a time series to use as reference. Defaults to a random series of `X`
+#'   if `NULL`. For multivariate series, this should be a matrix with the same characteristics as
+#'   the matrices in `X`. **It will be z-normalized**.
+#' @param znorm Logical flag. Should z-scores be calculated for `X` before processing?
 #'
 #' @details
 #'
-#' This works only if the series are \emph{z-normalized}, since the output will also have this
+#' This works only if the series are *z-normalized*, since the output will also have this
 #' normalization.
 #'
-#' The resulting centroid will have the same length as \code{centroid} if provided. Otherwise, there
-#' are two possibilities: if all series from \code{X} have the same length, all of them will be used
-#' as-is, and the output will have the same length as the series; if series have different lengths,
-#' a series will be chosen at random and used as reference. The output series will then have the
-#' same length as the chosen series.
+#' The resulting centroid will have the same length as `centroid` if provided. Otherwise, there are
+#' two possibilities: if all series from `X` have the same length, all of them will be used as-is,
+#' and the output will have the same length as the series; if series have different lengths, a
+#' series will be chosen at random and used as reference. The output series will then have the same
+#' length as the chosen series.
 #'
 #' This centroid computation is casted as an optimization problem called maximization of Rayleigh
-#' Quotient. It depends on the \code{\link{SBD}} algorithm. See the cited article for more details.
+#' Quotient. It depends on the [SBD()] algorithm. See the cited article for more details.
 #'
 #' @return Centroid time series (z-normalized).
 #'
 #' @references
 #'
 #' Paparrizos J and Gravano L (2015). ``k-Shape: Efficient and Accurate Clustering of Time Series.''
-#' In \emph{Proceedings of the 2015 ACM SIGMOD International Conference on Management of Data},
-#' series SIGMOD '15, pp. 1855-1870. ISBN 978-1-4503-2758-9,
-#' \url{http://doi.org/10.1145/2723372.2737793}.
+#' In *Proceedings of the 2015 ACM SIGMOD International Conference on Management of Data*, series
+#' SIGMOD '15, pp. 1855-1870. ISBN 978-1-4503-2758-9, \url{http://doi.org/10.1145/2723372.2737793}.
 #'
 #' @seealso
 #'
-#' \code{\link{SBD}}, \code{\link{zscore}}
+#' [SBD()], [zscore()]
 #'
 #' @examples
 #'
@@ -121,7 +120,7 @@ shape_extraction <- function(X, centroid = NULL, znorm = FALSE) {
     P <- diag(nc) - 1 / nc * matrix(1, nc, nc)
     M <- P %*% S %*% P
 
-    ksc <- eigen(M)$vectors[ , 1L, drop = TRUE]
+    ksc <- Re(eigen(M)$vectors[ , 1L, drop = TRUE])
 
     d1 <- lnorm(A[1L, , drop = TRUE] - ksc, 2)
     d2 <- lnorm(A[1L, , drop = TRUE] + ksc, 2)
